---
name: Demand a feature
about: Demand a feature
labels:
---

* Don't be too specific, give me room to guess what you want
* Use an entitled tone in your request
* Make further demands, such as when you want this to be ready
* If possible, make threats or preemptively insult the developers in case the feature doesn't live up to expectation
